import requests


class Session(object):
    url_login = 'https://www.uctenkovka.cz/api/web/auth/login'
    url_upload = 'https://www.uctenkovka.cz/api/web/player/receipts/'
    host = 'www.uctenkovka.cz'

    def __init__(self, username, password, token=None):
        self.http_session = requests.Session()
        if token is None:
            response = self.http_session.post(self.url_login,
                                              json={'password': password,
                                                    'username': username})
            if response.status_code < 200 or response.status_code >= 300:
                raise ConnectionRefusedError(
                    "Login didn't succeed. Returned code was {}."
                    .format(response.status_code))
            self.token = 'Bearer ' + response.json()['accessToken']
        else:
            self.token = token

    def register(self, code, date, time, amount, simple_mode=False):
        """Register the receipt to the url.

        Example:
            code = '01234567-89abcdef'  ==> bkp (1x '-')
            code = 'abcdefgh-0123-4567' ==> fik (2x '-' + 3rd seg = '4')
            date = '2019-02-09'         ==> 9th of Feb 2019
            time = '15:10'              ==> 15 hours 10 minutes
          amount = '109367'             ==> 1093.67 currency (usually CZK)
                                            Yes, transactions can have
                                            decimal points, for ex.
                                            when paying w/ credit card.

        :type code: str
        :type date: str
        :type time: str
        :type amount: str
        :type simple_mode: bool
        """

        if code.count('-') == 2:
            response = self.http_session.post(self.url_upload,
                                              json=dict(amount=amount,
                                                        date=date,
                                                        time=time,
                                                        simpleMode=simple_mode,
                                                        fik=code,
                                                        phone=None),
                                              headers={
                                                  "Authorization": self.token,
                                                  "Host": self.host})
        else:
            response = self.http_session.post(self.url_upload,
                                              json=dict(amount=amount,
                                                        date=date,
                                                        time=time,
                                                        simpleMode=simple_mode,
                                                        bkp=code,
                                                        phone=None),
                                              headers={
                                                  "Authorization": self.token,
                                                  "Host": self.host})
        return response.status_code


